@@ -311,10 +311,10 @@ class ACO(object):
                               'not isPresent in the pheromone_update parameter.'
             if kwargs['pheromone_update']['strategy'].lower() == 'as':
                 update_strategy_ = updateAS(kwargs.get('graph_type', 'D'),
-                                            kwargs['pheromone_update'].get('bag_size', False))
+                                            kwargs['pheromone_update'].get('elite', False))
             elif kwargs['pheromone_update']['strategy'].lower() == 'mmas':
                 update_strategy_ = updateMMAS(kwargs.get('graph_type', 'D'),
-                                              kwargs['pheromone_update'].get('bag_size', False))
+                                              kwargs['pheromone_update'].get('elite', False))
             elif kwargs['pheromone_update']['strategy'].lower() == 'acs':
                 update_strategy_ = updateACS(kwargs.get('graph_type', 'D'))
             else:
@@ -341,14 +341,14 @@ class ACO(object):
 
         elif isinstance(kwargs.get('pheromone_update', None), dict):
             if kwargs['pheromone_update']['strategy'].lower() == 'as':
-                if kwargs['pheromone_update'].get('bag_size', None) is not None:
-                    return {'bag_size': kwargs['pheromone_update']['bag_size'],
+                if kwargs['pheromone_update'].get('elite', None) is not None:
+                    return {'elite': kwargs['pheromone_update']['elite'],
                             'weight': kwargs['pheromone_update'].get('weight', 1.0)}
                 return {'weight': 1.0}
             elif kwargs['pheromone_update']['strategy'].lower() == 'mmas':
-                if kwargs['pheromone_update'].get('bag_size', None) is not None:
+                if kwargs['pheromone_update'].get('elite', None) is not None:
                     return {'limits': tuple(kwargs['pheromone_update'].get('limits', (0, 1))),
-                            'bag_size': kwargs['pheromone_update']['bag_size'],
+                            'elite': kwargs['pheromone_update']['elite'],
                             'weight': kwargs['pheromone_update'].get('weight', 1.0)}
                 return {'limits': tuple(kwargs['pheromone_update'].get('limits', (0, 1))),
                         'weight': kwargs['pheromone_update'].get('weight', 1.0)}
@@ -561,15 +561,15 @@ def getRandomWalk(initial_position: int, current_path: np.ndarray, adjacency_mat
     
         if len(movements) == 1:
             mov = movements[0]
-        
-        elif R is not None and np.random.uniform() < R:   # Random selection of the move
-            mov = np.random.choice(movements)
-            
+    
         elif Q is not None and np.random.uniform() < Q:    # Deterministic selection of the move
             probs = stochasticAS(
                 initial_position, np.array(movements), heuristic, pheromone, alpha)        
             mov = movements[np.argmax(probs)]
-            
+
+        elif R is not None and np.random.uniform() < R:   # Random selection of the move
+            mov = np.random.choice(movements)
+                       
         else:  # Stochastic selection of the next move            
             probs = stochasticAS(
                 initial_position, np.array(movements), heuristic, pheromone, alpha)
@@ -820,8 +820,7 @@ def generatePathsACS(ants: list, graph: np.ndarray, H: np.ndarray, P: np.ndarray
     return new_ants
 
 
-def evaluateAnts(ants: list, objectiveFunction: ObjectiveFunction, parallel_evaluation: bool,
-                 n_jobs: int = 1) -> np.ndarray:
+def evaluateAnts(ants: list, objectiveFunction: ObjectiveFunction) -> np.ndarray:
     """
     Function that performs the evaluation of the paths traversed by the ants using the defined cost
     function.
@@ -835,25 +834,12 @@ def evaluateAnts(ants: list, objectiveFunction: ObjectiveFunction, parallel_eval
         Subclass of antco.optim.ObjectiveFunction defined by the user. This function will be
         maximized.
 
-    parallel_evaluation: bool
-        Parameter indicating whether to carry out the evaluation in parallel.
-
-    n_jobs: int
-        If parallel_evaluation is True, number of processes to run in parallel.
-
     Returns
     -------
     :np.ndarray (len(ants)), dtype=np.float64
         Scores associated with the ants.
     """
-    if parallel_evaluation:
-        ant_scores = joblib.Parallel(n_jobs=n_jobs)(
-            joblib.delayed(objectiveFunction)((ant, idx)) for idx, ant in enumerate(ants))
-        # HACK: Parallel execution does not return indexes in order
-        for score, idx in ant_scores:
-            ant_scores[idx] = score
-    else:
-        ant_scores = np.array([
+    ant_scores = np.array([
             objectiveFunction((ant, idx)) for idx, ant in enumerate(ants)], dtype=np.float64)[:, 0]
 
     return ant_scores
